@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 
-from . import HobokenTestCase
+from . import HobokenTestCase, is_python3
 from .. import HobokenApplication, condition
 from ..application import HobokenBaseApplication, Route, halt, pass_route
 from ..matchers import RegexMatcher
 from ..exceptions import *
+import os
 import re
 import sys
 import unittest
@@ -137,7 +138,7 @@ class TestHaltHelper(HobokenTestCase):
 
         # The 'text' attribute of a webob Request only supports unicode
         # strings on Python 2.X, so we need to make this unicode.
-        if sys.version_info[0] < 3:
+        if not is_python3():
             self.halt_body = unicode(body)
         else:
             self.halt_body = body
@@ -364,6 +365,14 @@ class TestMiscellaneousMethods(HobokenTestCase):
 
         self.assert_equal(resp.status_code, 405)
 
+    def test_will_error_on_invalid_body(self):
+        req = mock.MagicMock()
+        resp = mock.MagicMock()
+        value = 123
+
+        with self.assert_raises(ValueError):
+            self.app.on_returned_body(req, resp, value)
+
 class TestConfig(HobokenTestCase):
     def test_can_get_set_values(self):
         self.app.config.foo = 'asdf'
@@ -376,6 +385,11 @@ class TestConfig(HobokenTestCase):
 
         self.assert_true('foo' not in self.app.config)
 
+    def test_will_fill_missing_views_dir(self):
+        app = HobokenApplication('', root_directory='foo')
+        expected_views = os.path.join('foo', 'views')
+        self.assert_equal(app.config.views_directory, expected_views)
+
 
 class TestInheritance(HobokenTestCase):
     def test_mixin_init_called(self):
